DaemonLspClient

Struct DaemonLspClient 

pub struct DaemonLspClient { /* private fields */ }
Client that connects to a running LSP daemon via Unix socket. Implements the same interface as LspClient for drop-in use.

Implementations

Source

impl DaemonLspClient

pub fn connect(project_root: &Path, lang_id: &str) -> Result<Self>

Connect to a running daemon.

pub fn ping(&mut self) -> Result<bool>

Check if the daemon has a ready server for our language.

pub fn open_file(&mut self, rel_path: &str, content: &str) -> Result<()>

Open a file.

pub fn get_definition( &mut self, rel_path: &str, line: u32, character: u32, ) -> Result<Option<LspLocation>>

Get definition.

pub fn get_references( &mut self, rel_path: &str, line: u32, character: u32, include_declaration: bool, ) -> Result<Vec<LspLocation>>

Get references.

pub fn get_implementations( &mut self, rel_path: &str, line: u32, character: u32, ) -> Result<Vec<LspLocation>>

Get implementations.

pub fn close_file(&mut self, rel_path: &str) -> Result<()>

Close a file.

pub fn refine_incremental( &mut self, delta: &FileDelta, root_dir: &Path, ) -> Result<usize>

Incrementally refine: notify the daemon of file changes from a FileDelta. The daemon will close deleted files, re-open modified files, and open added files in the appropriate LSP servers. Returns the number of files processed.