Module refactor

Module refactor 

Graph refactoring operations.

Preview and apply structural changes: rename, merge, split, extract.

Structs

Change
A single change in a refactoring operation.
RefactorPreview
A preview of changes that a refactoring operation would make.
SplitDefinition
Definition for how to split a node.

Enums

ChangeType
Type of change in a refactoring operation.

Functions

apply_extract
Apply an extract operation.
apply_merge
Apply a merge operation.
apply_rename
Apply a node rename operation.
apply_split
Apply a split operation. Returns the IDs of created nodes.
move_to_layer
Move a node to a different layer.
preview_extract
Preview extracting nodes into a new parent/group.
preview_merge
Preview what would change if two nodes are merged.
preview_rename
Preview what would change if a node is renamed.
preview_split
Preview what would change if a node is split.
update_title
Update a node’s title.