pub fn preview_split(
graph: &Graph,
node_id: &str,
splits: &[SplitDefinition],
) -> Option<RefactorPreview>Expand description
Preview what would change if a node is split.
pub fn preview_split(
graph: &Graph,
node_id: &str,
splits: &[SplitDefinition],
) -> Option<RefactorPreview>Preview what would change if a node is split.