Module parser
gid_
core
0.3.2
Module parser
Module Items
Functions
In crate gid_
core
gid_core
Module
parser
Functions

find_
graph_
file
Find the graph file in a project directory. Searches: .gid/graph.yml, .gid/graph.yaml, graph.yml, graph.yaml
find_
graph_
file_
walk_
up
Find the graph file by walking up from a starting directory. Like
git
searching for
.git/
, this walks up the directory tree until it finds a
.gid/graph.yml
(or reaches the filesystem root).
find_
project_
root
Find the
.gid/
directory by walking up from a starting directory. Returns the parent directory that contains
.gid/
, not the
.gid/
path itself.
load_
graph
Load a graph from a YAML file.
save_
graph
Save a graph to a YAML file.