Graph refactoring operations.
Preview and apply structural changes: rename, merge, split, extract.
Structs
- Change
- A single change in a refactoring operation.
- Refactor
Preview - A preview of changes that a refactoring operation would make.
- Split
Definition - Definition for how to split a node.
Enums
- Change
Type - Type of change in a refactoring operation.
Functions
- apply_
extract - Apply an extract operation.
- apply_
merge - Apply a merge operation.
- apply_
rename - Apply a node rename operation.
- apply_
split - Apply a split operation. Returns the IDs of created nodes.
- move_
to_ layer - Move a node to a different layer.
- preview_
extract - Preview extracting nodes into a new parent/group.
- preview_
merge - Preview what would change if two nodes are merged.
- preview_
rename - Preview what would change if a node is renamed.
- preview_
split - Preview what would change if a node is split.
- update_
title - Update a node’s title.